#
# spec file for package eina
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           eina
Version:        1.7.4
Release:        18.1
Summary:        Core EFL (Enlightenment Foundation Library) to handle various data types
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Core EFL (Enlightenment Foundation Library) to handle various data types. Introduced in version DR17-0.16.999.050

%package -n libeina1
Summary:        Eina Dynamic Libraries
Group:          System/Libraries
Obsoletes:	libeina

%description -n libeina1
Eina is core EFL (Enlightenment Foundation Libraries) library to handle various data types.

%package devel
Summary:        Eina headers, static libraries, documentation and test programs
Group:          Development/Libraries/C and C++
Requires:       libeina1 = %{version}

%description devel
Headers, static libraries, test programs and documentation for eina

%package doc-html
Summary:        HTML documentation of Eina
Group:          Documentation/HTML

%description doc-html
Documentation of Eina library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Eina
Group:          Documentation/Man

%description doc-man
Documentation of Eina library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

# remove __DATE__ and __TIME__
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i -e "s/__TIME__/\"$FAKE_BUILDTIME\"/g" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/g" src/lib/eina_hamster.c

%configure \
        --disable-static \
        --enable-doc
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"
# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix line endings
find %{buildroot}%{_docdir} -name '*.eps' | xargs sed -i 's@\r@\n@g'
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

%clean
rm -rf %{buildroot}

%post -n libeina1 -p /sbin/ldconfig

%postun -n libeina1 -p /sbin/ldconfig

%files -n libeina1
%defattr(-,root,root)
%{_libdir}/libeina.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/eina-1/
%{_libdir}/pkgconfig/eina.pc
%{_libdir}/libeina.so

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-18.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Eina 1.7.3:
  * Fix EINA_INLIST_FOREACH_SAFE macro
  * Add XML output to doc
  * Add installation rule for doc
  * Fix build for Windows platforms.
* Wed Dec 19 2012 sleep_walker@suse.cz
- build documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Tue Nov 13 2012 sleep_walker@suse.cz
- correct license version
* Tue Nov 13 2012 sleep_walker@suse.cz
- remove remains of doc subpackage
* Tue Nov 13 2012 sleep_walker@suse.cz
- applied spec-cleaner
* Tue Nov 13 2012 sleep_walker@suse.cz
- removed autoupdate entries from changelog
* Mon Nov 12 2012 sleep_walker@suse.cz
- remove configure patch as it is useless
- remove __DATE__ and __TIME__ and use last changelog entry instead
* Sat Oct 20 2012 simon@simotek.net
- bump to 1.7.1
* Sun Sep  9 2012 sleep_walker@suse.cz
- let there be eina-bench-cmp
* Fri Sep  7 2012 sleep_walker@suse.cz
- revert spec file make_install modification
* Fri Sep  7 2012 sleep_walker@suse.cz
- refresh patch
* Tue Jun 19 2012 sleep_walker@suse.cz
- fix description
* Mon Apr 30 2012 sleep_walker@suse.cz
- updated patch of configure
* Wed Mar 21 2012 sleep_walker@suse.cz
- refreshing configure.patch
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf automake libtool
* Fri Dec 16 2011 sleep_walker@suse.cz
- pre_configure --> pre_configure_hook
* Thu Dec 15 2011 sleep_walker@suse.cz
- refresh configure.patch to revision 66263
* Mon Dec 12 2011 sleep_walker@suse.cz
- refresh configure.patch to revision 66086
* Sat Dec 10 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 40ebd546fdf4c2971f59f645e4f374ae35589a67
* Mon Oct 17 2011 tcech@suse.com
- attempt for fix CentOS 5 and SLES10
* Mon Oct 17 2011 tcech@suse.com
- add fix to detect revision correctly
* Sun Oct 16 2011 tcech@suse.com
- add autoreconf before configure
* Thu Oct 13 2011 tcech@suse.com
- first attempt for debian build
* Mon Aug 15 2011 sleep_walker@suse.cz
- change %%make_install to %%makeinstall to support more distributions
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package of Eina version 1.0.0
